# -*- coding: utf-8 -*-
# Generated by Django 1.11.26 on 2020-03-30 14:42
from __future__ import unicode_literals

from django.db import migrations, models
import djangoldp.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Dashboard',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('urlid', djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True)),
                ('size', models.CharField(choices=[('1', '1'), ('2', '2'), ('3', '3')], default='1', max_length=1)),
                ('content', models.CharField(max_length=255)),
            ],
            options={
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'control'),
            },
        ),
    ]
