# -*- coding: utf-8 -*-
# Generated by Django 1.11.26 on 2020-03-30 15:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_dashboard', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dashboard',
            name='content',
            field=models.TextField(),
        ),
    ]
